You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:05:21 UTC

svn commit: r1591058 [13/15] - in /openoffice/trunk/main: ./ accessibility/bridge/org/openoffice/java/accessibility/ accessibility/bridge/source/java/ accessibility/inc/accessibility/extended/ accessibility/inc/accessibility/standard/ accessibility/sou...

Modified: openoffice/trunk/main/framework/source/helper/statusindicatorfactory.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/helper/statusindicatorfactory.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/helper/statusindicatorfactory.cxx (original)
+++ openoffice/trunk/main/framework/source/helper/statusindicatorfactory.cxx Tue Apr 29 19:05:05 2014
@@ -269,7 +269,7 @@ void StatusIndicatorFactory::end(const c
     else
     {
         // Our stack is empty. No further child exists.
-        // Se we must "end" our progress realy
+        // Se we must "end" our progress really
         if (xProgress.is())
             xProgress->end();
         // Now hide the progress bar again.
@@ -367,7 +367,7 @@ void StatusIndicatorFactory::implts_make
         xParentWindow = xPluggWindow;
 
     // dont disturb user in case he put the loading document into the background!
-    // Supress any setVisible() or toFront() call in case the initial show was
+    // Suppress any setVisible() or toFront() call in case the initial show was
     // already made.
     css::uno::Reference< css::awt::XWindow2 > xVisibleCheck(xParentWindow, css::uno::UNO_QUERY);
     sal_Bool bIsVisible = sal_False;
@@ -394,11 +394,11 @@ void StatusIndicatorFactory::implts_make
         }
     }
 
-    // Ok the window should be made visible ... becuase it isnt currently visible.
+    // Ok the window should be made visible ... because it isn't currently visible.
     // BUT ..!
     // We need a Hack for our applications: They get her progress from the frame directly
     // on saving documents. Because there is no progress set on the MediaDescriptor.
-    // But that's wrong. In case the document was opened hidden, they shouldnt use any progress .-(
+    // But that's wrong. In case the document was opened hidden, they shouldn't use any progress .-(
     // They only possible workaround: dont show the parent window here, if the document was opened hidden.
     sal_Bool bHiddenDoc = sal_False;
     if (xFrame.is())
@@ -421,7 +421,7 @@ void StatusIndicatorFactory::implts_make
         return;
 
     // OK: The document was not opened in hidden mode ...
-    // and the window isnt already visible.
+    // and the window isn't already visible.
     // Show it and bring it to front.
     // But before we have to be sure, that our internal used helper progress
     // is visible too.

Modified: openoffice/trunk/main/framework/source/helper/uiconfigelementwrapperbase.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/helper/uiconfigelementwrapperbase.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/helper/uiconfigelementwrapperbase.cxx (original)
+++ openoffice/trunk/main/framework/source/helper/uiconfigelementwrapperbase.cxx Tue Apr 29 19:05:05 2014
@@ -432,7 +432,7 @@ void SAL_CALL UIConfigElementWrapperBase
         if( pInfoHelper == NULL )
 		{
 			// Define static member to give structure of properties to baseclass "OPropertySetHelper".
-			// "impl_getStaticPropertyDescriptor" is a non exported and static funtion, who will define a static propertytable.
+			// "impl_getStaticPropertyDescriptor" is a non exported and static function, who will define a static propertytable.
 			// "sal_True" say: Table is sorted by name.
             static ::cppu::OPropertyArrayHelper aInfoHelper( impl_getStaticPropertyDescriptor(), sal_True );
 			pInfoHelper = &aInfoHelper;

Modified: openoffice/trunk/main/framework/source/helper/uielementwrapperbase.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/helper/uielementwrapperbase.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/helper/uielementwrapperbase.cxx (original)
+++ openoffice/trunk/main/framework/source/helper/uielementwrapperbase.cxx Tue Apr 29 19:05:05 2014
@@ -220,7 +220,7 @@ void SAL_CALL UIElementWrapperBase::getF
         if( pInfoHelper == NULL )
 		{
 			// Define static member to give structure of properties to baseclass "OPropertySetHelper".
-			// "impl_getStaticPropertyDescriptor" is a non exported and static funtion, who will define a static propertytable.
+			// "impl_getStaticPropertyDescriptor" is a non exported and static function, who will define a static propertytable.
 			// "sal_True" say: Table is sorted by name.
             static ::cppu::OPropertyArrayHelper aInfoHelper( impl_getStaticPropertyDescriptor(), sal_True );
 			pInfoHelper = &aInfoHelper;

Modified: openoffice/trunk/main/framework/source/helper/vclstatusindicator.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/helper/vclstatusindicator.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/helper/vclstatusindicator.cxx (original)
+++ openoffice/trunk/main/framework/source/helper/vclstatusindicator.cxx Tue Apr 29 19:05:05 2014
@@ -67,7 +67,7 @@ VCLStatusIndicator::VCLStatusIndicator(c
 {
     if (!m_xParentWindow.is())
         throw css::uno::RuntimeException(
-                ::rtl::OUString::createFromAscii("Cant work without a parent window!"),
+                ::rtl::OUString::createFromAscii("Can't work without a parent window!"),
                 static_cast< css::task::XStatusIndicator* >(this));
 }
    

Modified: openoffice/trunk/main/framework/source/inc/accelerators/acceleratorcache.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/accelerators/acceleratorcache.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/accelerators/acceleratorcache.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/accelerators/acceleratorcache.hxx Tue Apr 29 19:05:05 2014
@@ -58,7 +58,7 @@ namespace framework
             
             copy-on-write ... How? Do the following:
  */
-class AcceleratorCache : public ThreadHelpBase // attention! Must be the first base class to guarentee right initialize lock ...
+class AcceleratorCache : public ThreadHelpBase // attention! Must be the first base class to guarantee right initialize lock ...
 {
     //______________________________________
     // const, types

Modified: openoffice/trunk/main/framework/source/inc/accelerators/acceleratorconfiguration.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/accelerators/acceleratorconfiguration.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/accelerators/acceleratorconfiguration.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/accelerators/acceleratorconfiguration.hxx Tue Apr 29 19:05:05 2014
@@ -87,7 +87,7 @@ typedef PresetHandler AcceleratorPresets
 /**
     implements a read/write access to the accelerator configuration.
  */
-class XMLBasedAcceleratorConfiguration : protected ThreadHelpBase                       // attention! Must be the first base class to guarentee right initialize lock ...
+class XMLBasedAcceleratorConfiguration : protected ThreadHelpBase                       // attention! Must be the first base class to guarantee right initialize lock ...
 									   , public    IStorageListener
 									   , public    ::cppu::OWeakObject
 									   , public    css::lang::XTypeProvider
@@ -305,7 +305,7 @@ class XMLBasedAcceleratorConfiguration :
 
 };
 
-class XCUBasedAcceleratorConfiguration : protected ThreadHelpBase                       // attention! Must be the first base class to guarentee right initialize lock ...
+class XCUBasedAcceleratorConfiguration : protected ThreadHelpBase                       // attention! Must be the first base class to guarantee right initialize lock ...
 									   , public    ::cppu::OWeakObject
 								       , public    css::lang::XTypeProvider
 									   , public    css::util::XChangesListener  

Modified: openoffice/trunk/main/framework/source/inc/accelerators/keymapping.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/accelerators/keymapping.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/accelerators/keymapping.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/accelerators/keymapping.hxx Tue Apr 29 19:05:05 2014
@@ -147,7 +147,7 @@ class KeyMapping
                     if this method returns sal_True!
 
             @return [boolean]
-                    sal_True if convertion was successfully.                                
+                    sal_True if conversion was successfully.                                
           */
         sal_Bool impl_st_interpretIdentifierAsPureKeyCode(const ::rtl::OUString& sIdentifier,
                                                                 sal_uInt16&      rCode      );

Modified: openoffice/trunk/main/framework/source/inc/accelerators/presethandler.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/accelerators/presethandler.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/accelerators/presethandler.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/accelerators/presethandler.hxx Tue Apr 29 19:05:05 2014
@@ -71,7 +71,7 @@ namespace framework
         "menubar"           "default"     "menubar"           
                             
  */
-class PresetHandler : private ThreadHelpBase // attention! Must be the first base class to guarentee right initialize lock ...
+class PresetHandler : private ThreadHelpBase // attention! Must be the first base class to guarantee right initialize lock ...
 {
     //-------------------------------------------
     // const
@@ -109,7 +109,7 @@ class PresetHandler : private ThreadHelp
 
         //---------------------------------------
         /** @short  because a concurrent access to the same storage from different implementations
-                    isnt supported, we have to share it with others.
+                    isn't supported, we have to share it with others.
                     
             @descr  This struct makes it possible to use any shared storage
                     in combination with a SingletonRef<> template ...
@@ -176,7 +176,7 @@ class PresetHandler : private ThreadHelp
         ::salhelper::SingletonRef< TSharedStorages > m_aSharedStorages;
         
         //---------------------------------------
-        /** @short  if we run in document mode, we cant use the global root storages!
+        /** @short  if we run in document mode, we can't use the global root storages!
                     We have to use a special document storage explicitly. */
         StorageHolder m_lDocumentStorages;
         
@@ -245,7 +245,7 @@ class PresetHandler : private ThreadHelp
         
             @descr  Because this class should be useable in combination
                     with ::salhelper::SingletonRef template this ctor
-                    cant have any special parameters!
+                    can't have any special parameters!
                     
             @param  xSMGR
                     points to an uno service manager, which is used internaly
@@ -337,7 +337,7 @@ class PresetHandler : private ThreadHelp
                     and we use e.g. "/en-US/default.xml" internaly.
                     
                     If no localization exists for this preset set, this class
-                    will work in default mode - means "no locale" - automaticly.
+                    will work in default mode - means "no locale" - automatically.
                     e.g. "/default.xml"
                     
             @throw  com::sun::star::uno::RuntimeException(!)
@@ -397,7 +397,7 @@ class PresetHandler : private ThreadHelp
         
             @descr  Note: Targets resist inside the user
                     layer. Normaly they are opened in read/write mode.
-                    But it will be opened readonly automaticly if that isnt possible
+                    But it will be opened readonly automatically if that isn't possible
                     (may be the file is write protected on the system ...).
 
             @param  sTarget
@@ -414,12 +414,12 @@ class PresetHandler : private ThreadHelp
                                                                  sal_Bool         bCreateIfMissing);
         
         //---------------------------------------
-        /** @short  do anything which is neccessary to flush all changes
+        /** @short  do anything which is necessary to flush all changes
                     back to disk.
                     
             @descr  We have to call commit on all cached sub storages on the
                     path from the root storage upside down to the working storage
-                    (which are not realy used, but required to be holded alive!).
+                    (which are not really used, but required to be holded alive!).
          */
         void commitUserChanges();
         

Modified: openoffice/trunk/main/framework/source/inc/accelerators/storageholder.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/accelerators/storageholder.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/accelerators/storageholder.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/accelerators/storageholder.hxx Tue Apr 29 19:05:05 2014
@@ -66,7 +66,7 @@ namespace framework
 /**
     TODO document me
  */
-class StorageHolder : private ThreadHelpBase // attention! Must be the first base class to guarentee right initialize lock ...
+class StorageHolder : private ThreadHelpBase // attention! Must be the first base class to guarantee right initialize lock ...
 {
     //-------------------------------------------
     // types
@@ -207,7 +207,7 @@ class StorageHolder : private ThreadHelp
             @descr  First this method try to open the requested sub element
                     using the given open mode. If it failed there is second step,
                     which tries to do the same again ... but removing a might existing
-                    WRITE flag from the open mode. The user can supress this fallback
+                    WRITE flag from the open mode. The user can suppress this fallback
                     handling by setting the parameter bAllowFallback to sal_False.
                     
             @param  xBaseStorage

Modified: openoffice/trunk/main/framework/source/inc/dispatch/loaddispatcher.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/dispatch/loaddispatcher.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/dispatch/loaddispatcher.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/dispatch/loaddispatcher.hxx Tue Apr 29 19:05:05 2014
@@ -87,7 +87,7 @@ class LoadDispatcher : private ThreadHel
 
     public:
 
-        /** @short  creates a new instance and initialize it with all neccessary parameters.
+        /** @short  creates a new instance and initialize it with all necessary parameters.
 
             @descr  Every instance of such LoadDispatcher can be used for the specified context only.
                     That means: It can be used to load any further requested content into tzhe here(!)
@@ -104,7 +104,7 @@ class LoadDispatcher : private ThreadHel
                     which define such target.
 
             @param  nSearchFlags
-                    used in case sTargetFrame isnt a special one.
+                    used in case sTargetFrame isn't a special one.
          */
         LoadDispatcher(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR       ,
                        const css::uno::Reference< css::frame::XFrame >&              xOwnerFrame ,

Modified: openoffice/trunk/main/framework/source/inc/dispatch/windowcommanddispatch.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/dispatch/windowcommanddispatch.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/dispatch/windowcommanddispatch.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/dispatch/windowcommanddispatch.hxx Tue Apr 29 19:05:05 2014
@@ -92,7 +92,7 @@ class WindowCommandDispatch : private Th
         /// knows the frame, where we dispatch our commands as weak reference
         css::uno::WeakReference< css::frame::XFrame > m_xFrame;
     
-        /// knows the VCL window (where the hard coded commands occured) as weak XWindow reference
+        /// knows the VCL window (where the hard coded commands occurred) as weak XWindow reference
         css::uno::WeakReference< css::awt::XWindow > m_xWindow;
     
     //___________________________________________

Modified: openoffice/trunk/main/framework/source/inc/loadenv/actionlockguard.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/loadenv/actionlockguard.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/loadenv/actionlockguard.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/loadenv/actionlockguard.hxx Tue Apr 29 19:05:05 2014
@@ -77,7 +77,7 @@ class ActionLockGuard : private ThreadHe
         //---------------------------------------
         /** @short  default ctor to initialize a "non working guard".
 
-            @descr  That can be usefull in cases, where no resource still exists,
+            @descr  That can be useful in cases, where no resource still exists,
                     but will be available next time. Then this guard can be used
                     in a mode "use guard for more then one resources".
          */
@@ -88,7 +88,7 @@ class ActionLockGuard : private ThreadHe
         }
 
         //---------------------------------------
-        /** @short  initialize new guard instance and lock the given resource immediatly.
+        /** @short  initialize new guard instance and lock the given resource immediately.
 
             @param  xLock
                     points to the outside resource, which should be locked.

Modified: openoffice/trunk/main/framework/source/inc/loadenv/loadenv.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/loadenv/loadenv.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/loadenv/loadenv.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/loadenv/loadenv.hxx Tue Apr 29 19:05:05 2014
@@ -210,7 +210,7 @@ class LoadEnv : private ThreadHelpBase
 
         /** @short  holds the information about the finished load process.
 
-            @descr  The content of m_xTargetFrame cant be used as valid indicator,
+            @descr  The content of m_xTargetFrame can't be used as valid indicator,
                     (in case the micht existing old document was reactivated)
                     we must hold the result of the load process explicitly.
          */
@@ -241,7 +241,7 @@ class LoadEnv : private ThreadHelpBase
             @throw  Currently there is no reason to throw such exception!
 
             @throw  A RuntimeException in case any internal process indicates, that
-                    the whole runtime cant be used any longer.
+                    the whole runtime can't be used any longer.
          */
         LoadEnv(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR)
             throw(LoadEnvException, css::uno::RuntimeException);
@@ -303,10 +303,10 @@ class LoadEnv : private ThreadHelpBase
                     This value is set to a default value "UNKNWON_CONTENT", which force
                     an internal check, if this content is loadable or not.
                     But may this check was already made by the caller of this method and
-                    passing this information to this LoadEnv instance can supress this
+                    passing this information to this LoadEnv instance can suppress this
                     might expensive check.
-                    That can be usefull in case this information is needed outside too,
-                    to decide if its neccessary to create some resources for this load
+                    That can be useful in case this information is needed outside too,
+                    to decide if its necessary to create some resources for this load
                     request ... or to reject the request imidiatly if it seems to be not
                     loadable in general.
 
@@ -315,7 +315,7 @@ class LoadEnv : private ThreadHelpBase
                     The real reason, a suitable message and ID will be given here immidiatly.
 
             @throw  A RuntimeException in case any internal process indicates, that
-                    the whole runtime cant be used any longer.
+                    the whole runtime can't be used any longer.
          */
         virtual void initializeLoading(const ::rtl::OUString&                                           sURL            ,
                                        const css::uno::Sequence< css::beans::PropertyValue >&           lMediaDescriptor,
@@ -335,7 +335,7 @@ class LoadEnv : private ThreadHelpBase
                     a frame with a controller/model inside can be possible. For loading
                     of a "non visible component" only an information about a successfully start
                     can be provided.
-                    Further it cant be guranteed, that the internal process runs synchronous.
+                    Further it can't be guaranteed, that the internal process runs synchronous.
                     Thats why we preferr using of specialized methods afterwards e.g. to:
                         - wait till the internal job will be finished
                           and get the results
@@ -346,7 +346,7 @@ class LoadEnv : private ThreadHelpBase
                     The reason, a suitable message and ID will be given here immidiatly.
 
             @throw  A RuntimeException in case any internal process indicates, that
-                    the whole runtime cant be used any longer.
+                    the whole runtime can't be used any longer.
          */
         virtual void startLoading()
             throw(LoadEnvException, css::uno::RuntimeException);
@@ -371,7 +371,7 @@ class LoadEnv : private ThreadHelpBase
             @throw  ... currently not used :-)
 
             @throw  A RuntimeException in case any internal process indicates, that
-                    the whole runtime cant be used any longer.
+                    the whole runtime can't be used any longer.
          */
         virtual sal_Bool waitWhileLoading(sal_uInt32 nTimeout = 0)
             throw(LoadEnvException, css::uno::RuntimeException);
@@ -477,7 +477,7 @@ class LoadEnv : private ThreadHelpBase
                     In such cases a RuntimeException would be to hard for the outside code :-)
 
             @throw  A RuntimeException in case any internal process indicates, that
-                    the whole runtime cant be used any longer.
+                    the whole runtime can't be used any longer.
          */
         void impl_reactForLoadingState()
             throw(LoadEnvException, css::uno::RuntimeException);
@@ -498,12 +498,12 @@ class LoadEnv : private ThreadHelpBase
             @attention  Not all types we know, are supported by filters. So it does not
                         indicates an error, if no suitable filter(loader etcpp will be found
                         for a type. But a type must be detected for the specified content.
-                        Otherwhise its an error and loading cant be finished successfully.
+                        Otherwise its an error and loading can't be finished successfully.
 
             @throw  A LoadEnvException if detection failed.
 
             @throw  A RuntimeException in case any internal process indicates, that
-                    the whole runtime cant be used any longer.
+                    the whole runtime can't be used any longer.
          */
         void impl_detectTypeAndFilter()
             throw(LoadEnvException, css::uno::RuntimeException);
@@ -531,7 +531,7 @@ class LoadEnv : private ThreadHelpBase
                     for the detected content type (must be done before by calling
                     impl_detectTypeAndFilter()). Because such handler does not depend
                     from a real target frame, location of such frame will be
-                    supressed here.
+                    suppressed here.
                     In case handle failed all new created resources will be
                     removed before a suitable exception is thrown.
                     (Excepting a RuntimeException occure!)
@@ -541,7 +541,7 @@ class LoadEnv : private ThreadHelpBase
             @throw  A LoadEnvException if handling failed.
 
             @throw  A RuntimeException in case any internal process indicates, that
-                    the whole runtime cant be used any longer.
+                    the whole runtime can't be used any longer.
          */
         sal_Bool impl_handleContent()
             throw(LoadEnvException, css::uno::RuntimeException);
@@ -562,7 +562,7 @@ class LoadEnv : private ThreadHelpBase
             @throw  A LoadEnvException if loading failed.
 
             @throw  A RuntimeException in case any internal process indicates, that
-                    the whole runtime cant be used any longer.
+                    the whole runtime can't be used any longer.
          */
         sal_Bool impl_loadContent()
             throw(LoadEnvException, css::uno::RuntimeException);
@@ -590,7 +590,7 @@ class LoadEnv : private ThreadHelpBase
                     In such cases a RuntimeException would be to hard for the outside code :-)
 
             @throw  A RuntimeException in case any internal process indicates, that
-                    the whole runtime cant be used any longer.
+                    the whole runtime can't be used any longer.
          */
         css::uno::Reference< css::frame::XFrame > impl_searchAlreadyLoaded()
             throw(LoadEnvException, css::uno::RuntimeException);
@@ -623,7 +623,7 @@ class LoadEnv : private ThreadHelpBase
                     In such cases a RuntimeException would be to hard for the outside code :-)
 
             @throw  A RuntimeException in case any internal process indicates, that
-                    the whole runtime cant be used any longer.
+                    the whole runtime can't be used any longer.
          */
         css::uno::Reference< css::frame::XFrame > impl_searchRecycleTarget()
             throw(LoadEnvException, css::uno::RuntimeException);
@@ -631,11 +631,11 @@ class LoadEnv : private ThreadHelpBase
         //_______________________________________
 
         /** @short  because showing of a frame is needed more then once ...
-                    it's implemented as an seperate method .-)
+                    it's implemented as an separate method .-)
 
             @descr  Note: Showing of a frame is bound to a special feature ...
                     a) If we recycle any existing frame, we must bring it to front.
-                       Showing of such frame isnt needed realy .. because we recycle
+                       Showing of such frame isn't needed really .. because we recycle
                        visible frames only!
                     b) If the document was already shown (e.g. by our progress implementation)
                        we do nothing here. The reason  behind: The document was already shown ..
@@ -662,7 +662,7 @@ class LoadEnv : private ThreadHelpBase
 
         /** @short  checks weather a frame is already used for another load request or not.
 
-            @descr  Such frames cant be used for our "recycle feature"!
+            @descr  Such frames can't be used for our "recycle feature"!
 
             @param  xFrame
                     the frame, which should be checked.

Modified: openoffice/trunk/main/framework/source/inc/loadenv/loadenvexception.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/loadenv/loadenvexception.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/pattern/frame.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/pattern/frame.hxx Tue Apr 29 19:05:05 2014
@@ -72,8 +72,8 @@ inline css::uno::Reference< css::frame::
 
     @descr  It try to close the given resource first.
             Delegating of the ownership can be influenced from
-            outside. If closing isnt possible (because the
-            needed interface isnt available) dispose() is tried instead.
+            outside. If closing isn't possible (because the
+            needed interface isn't available) dispose() is tried instead.
             Al possible exception are handled inside.
             So the user of this method has to look for the return value only.
             
@@ -111,10 +111,10 @@ inline sal_Bool closeIt(const css::uno::
     catch(const css::lang::DisposedException&)
         {} // disposed is closed is ...
     catch(const css::uno::RuntimeException&)
-        { throw; } // shouldnt be suppressed!
+        { throw; } // shouldn't be suppressed!
     catch(const css::uno::Exception&)
         { return sal_False;  } // ??? We defined to return a boolen value instead of throwing exceptions ...
-                               // (OK: RuntimeExceptions shouldnt be catched inside the core ..)
+                               // (OK: RuntimeExceptions shouldn't be catched inside the core ..)
 
     return sal_True;
 }

Modified: openoffice/trunk/main/framework/source/inc/pattern/storages.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/pattern/storages.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/pattern/storages.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/pattern/storages.hxx Tue Apr 29 19:05:05 2014
@@ -62,7 +62,7 @@ css::uno::Reference< css::embed::XStorag
                                                                            const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR    ,
                                                                                  sal_Bool                                                bReadOnly)
 {
-    // error during opening the temp file isnt realy a runtime error -> handle it gracefully
+    // error during opening the temp file isn't really a runtime error -> handle it gracefully
     css::uno::Reference< css::io::XOutputStream > xTempFile(xSMGR->createInstance(SERVICENAME_TEMPFILE), css::uno::UNO_QUERY);
     if (!xTempFile.is())
         return css::uno::Reference< css::embed::XStorage >(); 

Modified: openoffice/trunk/main/framework/source/inc/pattern/window.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/pattern/window.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/inc/pattern/window.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/pattern/window.hxx Tue Apr 29 19:05:05 2014
@@ -74,7 +74,7 @@ static ::rtl::OUString getWindowState(co
     
     ByteString sWindowState;
     Window*    pWindow     = VCLUnoHelper::GetWindow(xWindow);
-    // check for system window is neccessary to guarantee correct pointer cast!
+    // check for system window is necessary to guarantee correct pointer cast!
     if (pWindow!=NULL && pWindow->IsSystemWindow())
 	{
 		sal_uLong nMask  = WINDOWSTATE_MASK_ALL;
@@ -102,7 +102,7 @@ static void setWindowState(const css::un
     ::vos::OClearableGuard aSolarGuard(Application::GetSolarMutex());
     
     Window* pWindow = VCLUnoHelper::GetWindow(xWindow);
-    // check for system window is neccessary to guarantee correct pointer cast!
+    // check for system window is necessary to guarantee correct pointer cast!
     if (
         (pWindow                  ) &&
         (pWindow->IsSystemWindow()) &&
@@ -128,8 +128,8 @@ static ::sal_Bool isTopWindow(const css:
     if (xTopWindowCheck.is())
     {
         // Note: Toolkit interface XTopWindow sometimes is used by real VCL-child-windows also .-)
-        // Be sure that these window is realy a "top system window".
-        // Attention ! Checking Window->GetParent() isnt the right approach here.
+        // Be sure that these window is really a "top system window".
+        // Attention ! Checking Window->GetParent() isn't the right approach here.
         // Because sometimes VCL create "implicit border windows" as parents even we created
         // a simple XWindow using the toolkit only .-(
         ::vos::OGuard aSolarLock(&Application::GetSolarMutex());

Modified: openoffice/trunk/main/framework/source/interaction/quietinteraction.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/interaction/quietinteraction.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/interaction/quietinteraction.cxx (original)
+++ openoffice/trunk/main/framework/source/interaction/quietinteraction.cxx Tue Apr 29 19:05:05 2014
@@ -94,7 +94,7 @@ QuietInteraction::QuietInteraction()
 
 void SAL_CALL QuietInteraction::handle( const css::uno::Reference< css::task::XInteractionRequest >& xRequest ) throw( css::uno::RuntimeException )
 {
-    // safe the request for outside analyzing everytime!
+    // safe the request for outside analyzing every time!
     css::uno::Any aRequest = xRequest->getRequest();
     /* SAFE { */
     WriteGuard aWriteLock(m_aLock);
@@ -138,7 +138,7 @@ void SAL_CALL QuietInteraction::handle( 
     {
         if (xFilter.is())
         {
-            // user selected filter wins everytime!
+            // user selected filter wins every time!
             xFilter->setFilter( aAmbigousFilterRequest.SelectedFilter );
             xFilter->select();
         }

Modified: openoffice/trunk/main/framework/source/jobs/helponstartup.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/jobs/helponstartup.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/jobs/helponstartup.cxx (original)
+++ openoffice/trunk/main/framework/source/jobs/helponstartup.cxx Tue Apr 29 19:05:05 2014
@@ -166,7 +166,7 @@ css::uno::Any SAL_CALL HelpOnStartup::ex
         return css::uno::Any();
 
     // check current state of the help module
-    // a) help isnt open                       => show default page for the detected module
+    // a) help isn't open                       => show default page for the detected module
     // b) help shows any other default page(!) => show default page for the detected module
     // c) help shows any other content         => do nothing (user travelled to any other content and leaved the set of default pages) 
     ::rtl::OUString sCurrentHelpURL                = its_getCurrentHelpURL();
@@ -227,7 +227,7 @@ void SAL_CALL HelpOnStartup::disposing(c
 
     // check for right environment.
     // If its not a DocumentEvent, which triggered this job,
-    // we cant work correctly! => return immediatly and do nothing
+    // we can't work correctly! => return immediately and do nothing
     ::rtl::OUString sEnvType = lEnvironment.getUnpackedValueOrDefault(PROP_ENVTYPE, ::rtl::OUString());
     if (!sEnvType.equals(ENVTYPE_DOCUMENTEVENT))
         return ::rtl::OUString();

Modified: openoffice/trunk/main/framework/source/jobs/job.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/jobs/job.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/jobs/jobdispatch.cxx (original)
+++ openoffice/trunk/main/framework/source/jobs/jobdispatch.cxx Tue Apr 29 19:05:05 2014
@@ -230,9 +230,9 @@ css::uno::Sequence< css::uno::Reference<
 
             If a job is already running, (it can only occure for asynchronous jobs)
             don't start the same job a second time. Queue in the given dispatch parameter
-            and return immediatly. If the current running job call us back, we will start this
+            and return immediately. If the current running job call us back, we will start this
             new dispatch request.
-            If no job is running - queue the parameter too! But then start the new job immediatly.
+            If no job is running - queue the parameter too! But then start the new job immediately.
             We have to queue it every time - because it hold us alive by ref count!
 
     @param  aURL
@@ -298,7 +298,7 @@ void JobDispatch::impl_dispatchEvent( /*
     // no jobs ... no execution
     // But a may given listener will know something ...
     // I think this operaton was finished successfully.
-    // It's not realy an error, if no registered jobs could be located.
+    // It's not really an error, if no registered jobs could be located.
     // Step over all found jobs and execute it
     int nExecutedJobs=0;
     for (int j=0; j<lJobs.getLength(); ++j)
@@ -329,7 +329,7 @@ void JobDispatch::impl_dispatchEvent( /*
         // Special mode for listener.
         // We dont notify it directly here. We delegate that
         // to the job implementation. But we must set ourself there too.
-        // Because this job must fake the source adress of the event.
+        // Because this job must fake the source address of the event.
         // Otherwhise the listener may will ignore it.
         if (xListener.is())
             pJob->setDispatchResultFake(xListener, xThis);
@@ -391,7 +391,7 @@ void JobDispatch::impl_dispatchService( 
     // Special mode for listener.
     // We dont notify it directly here. We delegate that
     // to the job implementation. But we must set ourself there too.
-    // Because this job must fake the source adress of the event.
+    // Because this job must fake the source address of the event.
     // Otherwhise the listener may will ignore it.
     if (xListener.is())
         pJob->setDispatchResultFake(xListener, xThis);
@@ -442,7 +442,7 @@ void JobDispatch::impl_dispatchAlias( /*
     // Special mode for listener.
     // We dont notify it directly here. We delegate that
     // to the job implementation. But we must set ourself there too.
-    // Because this job must fake the source adress of the event.
+    // Because this job must fake the source address of the event.
     // Otherwhise the listener may will ignore it.
     if (xListener.is())
         pJob->setDispatchResultFake(xListener, xThis);

Modified: openoffice/trunk/main/framework/source/jobs/jobexecutor.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/jobs/jobexecutor.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/jobs/joburl.cxx (original)
+++ openoffice/trunk/main/framework/source/jobs/joburl.cxx Tue Apr 29 19:05:05 2014
@@ -82,7 +82,7 @@ JobURL::JobURL( /*IN*/ const ::rtl::OUSt
         sal_Int32 t = JOBURL_PROTOCOL_LEN;
         do
         {
-            // seperate all token of "{[event=<name>],[alias=<name>],[service=<name>]}"
+            // separate all token of "{[event=<name>],[alias=<name>],[service=<name>]}"
             ::rtl::OUString sToken = sURL.getToken(0, JOBURL_PART_SEPERATOR, t);
             ::rtl::OUString sPartValue    ;
             ::rtl::OUString sPartArguments;
@@ -155,7 +155,7 @@ sal_Bool JobURL::isValid() const
     @return     <TRUE/> if an event part of the job URL exist and the out parameter
                 sEvent was filled.
 
-    @attention  The out parameter will be reseted everytime. Don't use it if method returns <FALSE/>!
+    @attention  The out parameter will be reseted every time. Don't use it if method returns <FALSE/>!
 */
 sal_Bool JobURL::getEvent( /*OUT*/ ::rtl::OUString& sEvent ) const
 {
@@ -188,7 +188,7 @@ sal_Bool JobURL::getEvent( /*OUT*/ ::rtl
     @return     <TRUE/> if an alias part of the job URL exist and the out parameter
                 sAlias was filled.
 
-    @attention  The out parameter will be reseted everytime. Don't use it if method returns <FALSE/>!
+    @attention  The out parameter will be reseted every time. Don't use it if method returns <FALSE/>!
 */
 sal_Bool JobURL::getAlias( /*OUT*/ ::rtl::OUString& sAlias ) const
 {
@@ -221,7 +221,7 @@ sal_Bool JobURL::getAlias( /*OUT*/ ::rtl
     @return     <TRUE/> if an service part of the job URL exist and the out parameter
                 sService was filled.
 
-    @attention  The out parameter will be reseted everytime. Don't use it if method returns <FALSE/>!
+    @attention  The out parameter will be reseted every time. Don't use it if method returns <FALSE/>!
 */
 sal_Bool JobURL::getService( /*OUT*/ ::rtl::OUString& sService ) const
 {
@@ -278,7 +278,7 @@ sal_Bool JobURL::implst_split( /*IN*/  c
     // Otherwhise we do nothing and return sal_False.
     if (bPartFound)
     {
-        // But may the part has optional arguments - seperated by a "?".
+        // But may the part has optional arguments - separated by a "?".
         // Do so - we set the return value with the whole part string.
         // Arguments will be set to an empty string as default.
         // If we detect the right sign - we split the arguments and overwrite the default.
@@ -321,7 +321,7 @@ void JobURL::impldbg_checkIt()
     JobURL::impldbg_checkURL("vnd.sun.star.job:service=;"          , E_UNKNOWN, ""         , ""       , ""           , NULL, NULL, NULL);
 
     // check combinations
-    // Note: No additional spaces or tabs are allowed after a seperator occured.
+    // Note: No additional spaces or tabs are allowed after a seperator occurred.
     // Tab and spaces before a seperator will be used as value!
     JobURL::impldbg_checkURL("vnd.sun.star.job:event=onMyEvent;alias=myAlias;service=css.Service"  , E_EVENT | E_ALIAS | E_SERVICE , "onMyEvent", "myAlias", "css.Service" , NULL, NULL, NULL);
     JobURL::impldbg_checkURL("vnd.sun.star.job:service=css.Service;alias=myAlias"                  , E_ALIAS | E_SERVICE           , ""         , "myAlias", "css.Service" , NULL, NULL, NULL);

Modified: openoffice/trunk/main/framework/source/jobs/shelljob.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/jobs/shelljob.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/jobs/shelljob.cxx (original)
+++ openoffice/trunk/main/framework/source/jobs/shelljob.cxx Tue Apr 29 19:05:05 2014
@@ -54,19 +54,19 @@ namespace framework{
 //_______________________________________________
 // definitions
 
-/** adress job configuration inside argument set provided on method execute(). */
+/** address job configuration inside argument set provided on method execute(). */
 static const ::rtl::OUString PROP_JOBCONFIG = ::rtl::OUString::createFromAscii("JobConfig");
 
-/** adress job configuration property "Command". */
+/** address job configuration property "Command". */
 static const ::rtl::OUString PROP_COMMAND = ::rtl::OUString::createFromAscii("Command");
 
-/** adress job configuration property "Arguments". */
+/** address job configuration property "Arguments". */
 static const ::rtl::OUString PROP_ARGUMENTS = ::rtl::OUString::createFromAscii("Arguments");
 
-/** adress job configuration property "DeactivateJobIfDone". */
+/** address job configuration property "DeactivateJobIfDone". */
 static const ::rtl::OUString PROP_DEACTIVATEJOBIFDONE = ::rtl::OUString::createFromAscii("DeactivateJobIfDone");
 
-/** adress job configuration property "CheckExitCode". */
+/** address job configuration property "CheckExitCode". */
 static const ::rtl::OUString PROP_CHECKEXITCODE = ::rtl::OUString::createFromAscii("CheckExitCode");
 
 //-----------------------------------------------
@@ -116,7 +116,7 @@ css::uno::Any SAL_CALL ShellJob::execute
     ::rtl::OUString sRealCommand = impl_substituteCommandVariables(sCommand);
         
     // Command is required as minimum.
-    // If it does not exists ... we cant do our job.
+    // If it does not exists ... we can't do our job.
     // Deactivate such miss configured job silently .-)
 	if (sRealCommand.getLength() < 1)
 	    return ShellJob::impl_generateAnswer4Deactivation();

Modified: openoffice/trunk/main/framework/source/layoutmanager/layoutmanager.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/layoutmanager/layoutmanager.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/layoutmanager/layoutmanager.cxx (original)
+++ openoffice/trunk/main/framework/source/layoutmanager/layoutmanager.cxx Tue Apr 29 19:05:05 2014
@@ -940,7 +940,7 @@ void LayoutManager::implts_backupProgres
         return;
 
     // safe a backup copy of the current progress!
-    // This copy will be used automaticly inside createProgressBar() which is called
+    // This copy will be used automatically inside createProgressBar() which is called
     // implictly from implts_doLayout() .-)
     m_xProgressBarBackup = m_aProgressBarElement.m_xUIElement;
 

Modified: openoffice/trunk/main/framework/source/layoutmanager/toolbarlayoutmanager.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/layoutmanager/toolbarlayoutmanager.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/layoutmanager/toolbarlayoutmanager.cxx (original)
+++ openoffice/trunk/main/framework/source/layoutmanager/toolbarlayoutmanager.cxx Tue Apr 29 19:05:05 2014
@@ -1225,7 +1225,7 @@ void ToolbarLayoutManager::implts_repare
                 uno::Reference< awt::XWindow > xWindow;
                 try
                 {
-                    // We have to retreive the window reference with try/catch as it is
+                    // We have to retrieve the window reference with try/catch as it is
                     // possible that all elements have been disposed!
                     xWindow = uno::Reference< awt::XWindow >( xUIElement->getRealInterface(), uno::UNO_QUERY );
                 }
@@ -1235,7 +1235,7 @@ void ToolbarLayoutManager::implts_repare
                 Window* pWindow = VCLUnoHelper::GetWindow( xWindow );
                 if ( pWindow )
                 {
-                    // Reparent our child windows acording to their current state.
+                    // Reparent our child windows according to their current state.
                     if ( pIter->m_bFloating )
                         pWindow->SetParent( pContainerWindow );
                     else

Modified: openoffice/trunk/main/framework/source/loadenv/loadenv.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/loadenv/loadenv.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/loadenv/targethelper.cxx (original)
+++ openoffice/trunk/main/framework/source/loadenv/targethelper.cxx Tue Apr 29 19:05:05 2014
@@ -88,8 +88,8 @@ sal_Bool TargetHelper::matchSpecialTarge
 -----------------------------------------------*/
 sal_Bool TargetHelper::isValidNameForFrame(const ::rtl::OUString& sName)
 {
-    // some special targets are realy special ones :-)
-    // E.g. the are realy used to locate one frame inside the frame tree.
+    // some special targets are really special ones :-)
+    // E.g. the are really used to locate one frame inside the frame tree.
     if (
         (!sName.getLength()                                 ) ||
         (TargetHelper::matchSpecialTarget(sName, E_HELPTASK)) ||

Modified: openoffice/trunk/main/framework/source/recording/dispatchrecordersupplier.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/recording/dispatchrecordersupplier.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/recording/dispatchrecordersupplier.cxx (original)
+++ openoffice/trunk/main/framework/source/recording/dispatchrecordersupplier.cxx Tue Apr 29 19:05:05 2014
@@ -90,7 +90,7 @@ DEFINE_INIT_SERVICE(
 /**
     @short  standard constructor to create instance
     @descr  Because an instance will be initialized by her interface methods
-            it's not neccessary to do anything here.
+            it's not necessary to do anything here.
  */
 DispatchRecorderSupplier::DispatchRecorderSupplier( const css::uno::Reference< css::lang::XMultiServiceFactory >& xFactory )
 		//	init baseclasses first!
--- openoffice/trunk/main/framework/source/inc/loadenv/loadenvexception.hxx (original)
+++ openoffice/trunk/main/framework/source/inc/loadenv/loadenvexception.hxx Tue Apr 29 19:05:05 2014
@@ -53,7 +53,7 @@ namespace css = ::com::sun::star;
             load environment only.
 
     @descr  Of course outside code must wrapp it, to transport
-            the occured information to its caller.
+            the occurred information to its caller.
 
     @author as96863
  */
@@ -106,11 +106,11 @@ class LoadEnvException
             ID_COULD_NOT_REACTIVATE_CONTROLLER,
 
             /** @short  inidcates an already running load operation. Of yourse the same
-                        instance cant be used for multiple load requests at the same time.
+                        instance can't be used for multiple load requests at the same time.
              */
             ID_STILL_RUNNING,
 
-            /** @short  sometiems we cant specify the reason for an error, because we
+            /** @short  sometiems we can't specify the reason for an error, because we
                         was interrupted by an called code in an unexpected way ...
              */
             ID_GENERAL_ERROR
@@ -128,7 +128,7 @@ class LoadEnvException
         /** @short  An ID, which make this exception unique among others. */
         sal_Int32 m_nID;
 
         /** @short  Contains the original exception, if any occured. */
         css::uno::Any m_exOriginal;
 
         /** TODO
@@ -144,7 +144,7 @@ class LoadEnvException
         /** @short  initialize a new instance with an ID.
             @descr  Some other items of this exception
                     (e.g. a suitable message) will be generated
-                    automaticly.
+                    automatically.
 
             @param  nID
                     One of the defined const IDs of this class.
@@ -160,7 +160,7 @@ class LoadEnvException
                     an wrap a detected exception into this one.
             @descr  Some other items of this exception
                     (e.g. a suitable message) will be generated
-                    automaticly.
+                    automatically.
 
             @param  nID
                     One of the defined const IDs of this class.
@@ -128,7 +128,7 @@ class LoadEnvException
         sal_Int32 m_nID;
 
-        /** @short  Contains the original exception, if any occured. */
+        /** @short  Contains the original exception, if any occurred. */
         css::uno::Any m_exOriginal;
 

Modified: openoffice/trunk/main/framework/source/inc/pattern/frame.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/inc/pattern/frame.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/jobs/job.cxx (original)
+++ openoffice/trunk/main/framework/source/jobs/job.cxx Tue Apr 29 19:05:05 2014
@@ -226,7 +226,7 @@ void Job::execute( /*IN*/ const css::uno
     css::uno::Reference< css::task::XJob >       xSJob;
     css::uno::Sequence< css::beans::NamedValue > lJobArgs = impl_generateJobArgs(lDynamicArgs);
 
-    // It's neccessary to hold us self alive!
+    // It's necessary to hold us self alive!
     // Otherwhise we might die by ref count ...
     css::uno::Reference< css::task::XJobListener > xThis(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
 
@@ -426,7 +426,7 @@ css::uno::Sequence< css::beans::NamedVal
     }
 
     // get the configuration data from the job data container ... if possible
     // Means: if this job has any configuration data. Note: only realy
     // filled lists will be set to the return structure at the end of this method.
     css::uno::Sequence< css::beans::NamedValue > lConfigArgs   ;
     css::uno::Sequence< css::beans::NamedValue > lJobConfigArgs;
@@ -477,8 +477,8 @@ css::uno::Sequence< css::beans::NamedVal
     @short  analyze the given job result and change the job configuration
     @descr  Note: Some results can be handled only, if this job has a valid configuration!
             For "not configured jobs" (means pure services) they can be ignored.
-            But these cases are handled by our JobData member. We can call it everytime.
-            It does the right things automaticly. E.g. if the job has no configuration ...
+            But these cases are handled by our JobData member. We can call it every time.
+            It does the right things automatically. E.g. if the job has no configuration ...
             it does nothing during setJobConfig()!
 
     @param  aResult
@@ -546,7 +546,7 @@ void Job::impl_reactForJobResult( /*IN*/
             at the global desktop instance. That will hold us
             alive and additional we get the information, if the
             office whish to shutdown. If then an internal job
-            is running we will have the chance to supress that
+            is running we will have the chance to suppress that
             by throwing a veto exception. If our internal wrapped
             job finished his work, we can release this listener
             connection.
@@ -707,7 +707,7 @@ void SAL_CALL Job::jobFinished( /*IN*/ c
     /* SAFE { */
     WriteGuard aWriteLock(m_aLock);
 
-    // It's neccessary to check this.
+    // It's necessary to check this.
     // May this job was cancelled by any other reason
     // some milliseconds before. :-)
     if (m_xJob.is() && m_xJob==xJob)
@@ -722,7 +722,7 @@ void SAL_CALL Job::jobFinished( /*IN*/ c
     }
 
     // And let the start method "execute()" finishing it's job.
     // But do it everytime. So any outside blocking code can finish
     // his work too.
     m_aAsyncWait.set();
 
@@ -787,7 +787,7 @@ void SAL_CALL Job::queryTermination( /*I
             Then we had not throwed a veto exception. But now we must agree with this situation and break
             all our internal processes. Its not a good idea to mark this instance as non startable any longer
             inside queryTermination() if no job was unning too. Because that would disable this job and may
-            the office does not realy shutdownm, because another listener has thrown the suitable exception.
+            the office does not really shutdownm, because another listener has thrown the suitable exception.
 
     @param  aEvent
                 describes the broadcaster and must be the desktop instance
@@ -426,7 +426,7 @@ css::uno::Sequence< css::beans::NamedVal
 
     // get the configuration data from the job data container ... if possible
-    // Means: if this job has any configuration data. Note: only realy
+    // Means: if this job has any configuration data. Note: only really
     // filled lists will be set to the return structure at the end of this method.
     css::uno::Sequence< css::beans::NamedValue > lConfigArgs   ;
@@ -722,7 +722,7 @@ void SAL_CALL Job::jobFinished( /*IN*/ c
 
     // And let the start method "execute()" finishing it's job.
-    // But do it everytime. So any outside blocking code can finish
+    // But do it every time. So any outside blocking code can finish
     // his work too.
     m_aAsyncWait.set();

Modified: openoffice/trunk/main/framework/source/jobs/jobdata.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/jobs/jobdata.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/jobs/jobdata.cxx (original)
+++ openoffice/trunk/main/framework/source/jobs/jobdata.cxx Tue Apr 29 19:05:05 2014
@@ -88,7 +88,7 @@ const sal_Char* JobData::PROP_CONTEXT   
 /**
     @short      standard ctor
     @descr      It initialize this new instance.
-                But for real working it's neccessary to call setAlias() or setService() later.
+                But for real working it's necessary to call setAlias() or setService() later.
                 Because we need the job data ...
 
     @param      xSMGR
@@ -159,7 +159,7 @@ JobData::~JobData()
 //________________________________
 /**
     @short      initalize this instance as a job with configuration
-    @descr      They given alias can be used to adress some configuraton data.
+    @descr      They given alias can be used to address some configuraton data.
                 We read it and fill our internal structures. Of course old informations
                 will be lost doing so.
 
@@ -255,7 +255,7 @@ void JobData::setService( const ::rtl::O
 //________________________________
 /**
     @short      initialize this instance with new job values.
-    @descr      It reads automaticly all properties of the specified
+    @descr      It reads automatically all properties of the specified
                 job (using it's alias name) and "register it" for the
                 given event. This registration will not be validated against
                 the underlying configuration! (That must be done from outside.
@@ -312,7 +312,7 @@ void JobData::setJobConfig( const css::u
     if (m_eMode==E_ALIAS)
     {
         // It doesn't matter if this config object was already opened before.
         // It doesn nothing here then ... or it change the mode automaticly, if
         // it was opened using another one before.
         ::rtl::OUString sKey;
         sKey  = ::rtl::OUString::createFromAscii(JOBCFG_ROOT);
@@ -377,7 +377,7 @@ void JobData::setResult( const JobResult
 //________________________________
 /**
     @short  set a new environment descriptor for this job
-    @descr  It must(!) be done everytime this container is initialized
+    @descr  It must(!) be done every time this container is initialized
             with new job datas e.g.: setAlias()/setEvent()/setService() ...
             Otherwhise the environment will be unknown!
  */
@@ -505,7 +505,7 @@ css::uno::Sequence< css::beans::NamedVal
     @short  return information, if this job is part of the global configuration package
             org.openoffice.Office.Jobs
     @descr  Because jobs can be executed by the dispatch framework using an uno service name
-            directly - an executed job must not have any configuration realy. Such jobs
+            directly - an executed job must not have any configuration really. Such jobs
             must provide the right interfaces only! But after finishing jobs can return
             some informations (e.g. for updating her configuration ...). We must know
             if such request is valid or not then.
@@ -527,9 +527,9 @@ sal_Bool JobData::hasConfig() const
                 And there exist two of them: one for an administrator ... and one for the
                 current user. We change it for the user layer only. So this JobDispatch can't be
                 started any more ... till the administrator change his timestamp.
-                That can be usefull for post setup scenarios, which must run one time only.
+                That can be useful for post setup scenarios, which must run one time only.
 
-                Note: This method don't do anything, if ths represented job doesn't have a configuration!
+                Note: This method don't do anything, if this represented job doesn't have a configuration!
  */
 void JobData::disableJob()
 {
@@ -542,7 +542,7 @@ void JobData::disableJob()
 
     // update the configuration
     // It doesn't matter if this config object was already opened before.
     // It doesn nothing here then ... or it change the mode automaticly, if
     // it was opened using another one before.
     ::rtl::OUStringBuffer sKey(256);
     sKey.appendAscii(JobData::EVENTCFG_ROOT                       );
@@ -675,7 +675,7 @@ css::uno::Sequence< ::rtl::OUString > Jo
 
     // get all alias names of jobs, which are part of this job list
     // But Some of them can be disabled by it's time stamp values.
-    // We create an additional job name list iwth the same size, then the original list ...
+    // We create an additional job name list with the same size, then the original list ...
     // step over all job entries ... check her time stamps ... and put only job names to the
     // destination list, which represent an enabled job.
     css::uno::Sequence< ::rtl::OUString > lAllJobs = xJobList->getElementNames();
@@ -726,7 +726,7 @@ css::uno::Sequence< ::rtl::OUString > Jo
                 But note: that does not set defaults for internal used members, which
                 does not relate to any job property! e.g. the reference to the global
                 uno service manager. Such informations are used for internal processes only
-                and are neccessary for our work.
+                and are necessary for our work.
  */
 void JobData::impl_reset()
 {
@@ -312,7 +312,7 @@ void JobData::setJobConfig( const css::u
     {
         // It doesn't matter if this config object was already opened before.
-        // It doesn nothing here then ... or it change the mode automaticly, if
+        // It doesn nothing here then ... or it change the mode automatically, if
         // it was opened using another one before.
         ::rtl::OUString sKey;
@@ -542,7 +542,7 @@ void JobData::disableJob()
     // update the configuration
     // It doesn't matter if this config object was already opened before.
-    // It doesn nothing here then ... or it change the mode automaticly, if
+    // It doesn nothing here then ... or it change the mode automatically, if
     // it was opened using another one before.
     ::rtl::OUStringBuffer sKey(256);

Modified: openoffice/trunk/main/framework/source/jobs/jobdispatch.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/jobs/jobdispatch.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/jobs/jobexecutor.cxx (original)
+++ openoffice/trunk/main/framework/source/jobs/jobexecutor.cxx Tue Apr 29 19:05:05 2014
@@ -160,7 +160,7 @@ JobExecutor::~JobExecutor()
 /**
     @short  implementation of XJobExecutor interface
     @descr  We use the given event to locate any registered job inside our configuration
-            and execute it. Further we control the lifetime of it and supress
+            and execute it. Further we control the lifetime of it and suppress
             shutdown of the office till all jobs was finished.
 
     @param  sEvent
@@ -175,7 +175,7 @@ void SAL_CALL JobExecutor::trigger( cons
 
     // Optimization!
     // Check if the given event name exist inside configuration and reject wrong requests.
     // This optimization supress using of the cfg api for getting event and job descriptions ...
     if (m_lEvents.find(sEvent) == m_lEvents.end())
         return;
 
@@ -232,7 +232,7 @@ void SAL_CALL JobExecutor::notifyEvent( 
 
     // Optimization!
     // Check if the given event name exist inside configuration and reject wrong requests.
     // This optimization supress using of the cfg api for getting event and job descriptions.
     // see using of m_lEvents.find() below ...
 
     // retrieve event context from event source
@@ -175,7 +175,7 @@ void SAL_CALL JobExecutor::trigger( cons
     // Optimization!
     // Check if the given event name exist inside configuration and reject wrong requests.
-    // This optimization supress using of the cfg api for getting event and job descriptions ...
+    // This optimization suppress using of the cfg api for getting event and job descriptions ...
     if (m_lEvents.find(sEvent) == m_lEvents.end())
         return;
@@ -232,7 +232,7 @@ void SAL_CALL JobExecutor::notifyEvent( 
     // Optimization!
     // Check if the given event name exist inside configuration and reject wrong requests.
-    // This optimization supress using of the cfg api for getting event and job descriptions.
+    // This optimization suppress using of the cfg api for getting event and job descriptions.
     // see using of m_lEvents.find() below ...
 

Modified: openoffice/trunk/main/framework/source/jobs/jobresult.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/jobs/jobresult.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/jobs/jobresult.cxx (original)
+++ openoffice/trunk/main/framework/source/jobs/jobresult.cxx Tue Apr 29 19:05:05 2014
@@ -69,7 +69,7 @@ JobResult::JobResult()
 {
     // reset the flag mask!
     // It will reset the accessible state of this object.
-    // That can be usefull if something will fail here ...
+    // That can be useful if something will fail here ...
     m_eParts = E_NOPART;
 }
 
@@ -126,7 +126,7 @@ JobResult::JobResult( /*IN*/ const css::
 
     // reset the flag mask!
     // It will reset the accessible state of this object.
-    // That can be usefull if something will fail here ...
+    // That can be useful if something will fail here ...
     m_eParts = E_NOPART;
 
     // analyze the result and update our other members
@@ -182,7 +182,7 @@ JobResult::JobResult( const JobResult& r
 */
 JobResult::~JobResult()
 {
     // Nothing realy to do here.
 }
 
 //________________________________
@@ -210,7 +210,7 @@ void JobResult::operator=( const JobResu
 /**
     @short      checks for existing parts of the analyzed result
     @descr      The internal flag mask was set after analyzing of the pure result.
-                An user of us can check here, if the required part was realy part
+                An user of us can check here, if the required part was really part
                 of this result. Otherwhise it would use invalid informations ...
                 by using our other members!
 
@@ -182,7 +182,7 @@ JobResult::JobResult( const JobResult& r
 JobResult::~JobResult()
 {
-    // Nothing realy to do here.
+    // Nothing really to do here.
 }
 

Modified: openoffice/trunk/main/framework/source/jobs/joburl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/jobs/joburl.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/loadenv/loadenv.cxx (original)
+++ openoffice/trunk/main/framework/source/loadenv/loadenv.cxx Tue Apr 29 19:05:05 2014
@@ -280,9 +280,9 @@ void LoadEnv::initializeLoading(const ::
     m_bReactivateControllerOnError  = sal_False         ;
     m_bLoaded                       = sal_False         ;
 
-    // try to find out, if its realy a content, which can be loaded or must be "handled"
+    // try to find out, if its really a content, which can be loaded or must be "handled"
     // We use a default value for this in-parameter. Then we have to start a complex check method
-    // internaly. But if this check was already done outside it can be supressed to perform
+    // internaly. But if this check was already done outside it can be suppressed to perform
     // the load request. We take over the result then!
     if (m_eContentType == E_UNSUPPORTED_CONTENT)
     {
@@ -292,7 +292,7 @@ void LoadEnv::initializeLoading(const ::
     }
 
     // make URL part of the MediaDescriptor
-    // It doesnt mater, if its already an item of it.
+    // It doesn't mater, if its already an item of it.
     // It must be the same value ... so we can overwrite it :-)
     m_lMediaDescriptor[::comphelper::MediaDescriptor::PROP_URL()] <<= sURL;
 
@@ -311,8 +311,8 @@ void LoadEnv::initializeLoading(const ::
     if (pIt != m_lMediaDescriptor.end())
         m_lMediaDescriptor.erase(pIt);
 
-    // patch the MediaDescriptor, so it fullfill the outside requirements
-    // Means especialy items like e.g. UI InteractionHandler, Status Indicator,
+    // patch the MediaDescriptor, so it fulfill the outside requirements
+    // Means especially items like e.g. UI InteractionHandler, Status Indicator,
     // MacroExecutionMode etcpp.
 
     /*TODO progress is bound to a frame ... How can we set it here? */
@@ -432,7 +432,7 @@ void LoadEnv::startLoading()
         bStarted = impl_loadContent();
 
     // not started => general error
-    // We cant say - what was the reason for.
+    // We can't say - what was the reason for.
     if (!bStarted)
         throw LoadEnvException(LoadEnvException::ID_GENERAL_ERROR);
 }
@@ -447,8 +447,8 @@ sal_Bool LoadEnv::waitWhileLoading(sal_u
     throw(LoadEnvException, css::uno::RuntimeException)
 {
     // Because its not a good idea to block the main thread
-    // (and we cant be shure that we are currently not used inside the
-    // main thread!), we cant use conditions here realy. We must yield
+    // (and we can't be sure that we are currently not used inside the
+    // main thread!), we can't use conditions here really. We must yield
     // in an intellegent manner :-)
 
     sal_Int32 nTime = nTimeout;
@@ -504,14 +504,14 @@ void LoadEnv::cancelLoading()
             /* Attention:
                 After returning from any cancel/dispose call, neither the frame nor weself
                 may be called back. Because only we can cancel this job, we already know
-                the result! => Thats why its not usefull nor neccessary to wait for any
+                the result! => Thats why its not useful nor necessary to wait for any
                 asynchronous listener notification.
             */
             m_bLoaded = sal_False;
             m_xAsynchronousJob.clear();
         }
-        // or may be its a content handler? Such handler cant be cancelled in its running
-        // operation :-( And we cant deregister us there again :-(
+        // or may be its a content handler? Such handler can't be cancelled in its running
+        // operation :-( And we can't deregister us there again :-(
         // => The only chance is an exception :-)
         else
             throw LoadEnvException(LoadEnvException::ID_STILL_RUNNING);
@@ -653,7 +653,7 @@ void LoadEnv::impl_setResult(sal_Bool bR
     impl_reactForLoadingState();
 
     // clearing of this reference will unblock waitWhileLoading()!
-    // So we must be shure, that loading process was realy finished.
+    // So we must be sure, that loading process was really finished.
     // => do it as last operation of this method ...
     m_xAsynchronousJob.clear();
 
@@ -701,7 +701,7 @@ LoadEnv::EContentType LoadEnv::classifyC
     //      all needed resources. If they are missing - the following
     //      load request will fail.
 
-    /* Attention: The following code cant work on such special URLs!
+    /* Attention: The following code can't work on such special URLs!
                   It should not break the office .. but it make no sense
                   to start expensive object creations and complex search
                   algorithm if its clear, that such URLs must be handled
@@ -832,7 +832,7 @@ void LoadEnv::impl_detectTypeAndFilter()
     ReadGuard aReadLock(m_aLock);
 
     // Attention: Because our stl media descriptor is a copy of an uno sequence
-    // we cant use as an in/out parameter here. Copy it before and dont forget to
+    // we can't use as an in/out parameter here. Copy it before and dont forget to
     // update structure afterwards again!
     css::uno::Sequence< css::beans::PropertyValue >        lDescriptor = m_lMediaDescriptor.getAsConstPropertyValueList();
     css::uno::Reference< css::lang::XMultiServiceFactory > xSMGR       = m_xSMGR;
@@ -862,7 +862,7 @@ void LoadEnv::impl_detectTypeAndFilter()
     aWriteLock.unlock();
     // <- SAFE
 
-    // But the type isnt enough. For loading sometimes we need more informations.
+    // But the type isn't enough. For loading sometimes we need more informations.
     // E.g. for our "_default" feature, where we recylce any frame which contains
     // and "Untitled" document, we must know if the new document is based on a template!
     // But this information is available as a filter property only.
@@ -895,7 +895,7 @@ void LoadEnv::impl_detectTypeAndFilter()
     // Then we have to add the property "AsTemplate".
     // We need this information to decide afterwards if we can use a "recycle frame"
     // for target "_default" or has to create a new one everytimes.
-    // On the other side we have to supress that, if this property already exists
+    // On the other side we have to suppress that, if this property already exists
     // and should trigger a special handling. Then the outside calli of this method here,
     // has to know, what he is doing .-)
 
@@ -944,7 +944,7 @@ sal_Bool LoadEnv::impl_handleContent()
     m_lMediaDescriptor >> lDescriptor;
     css::util::URL aURL = m_aURL;
 
     // get neccessary container to query for a handler object
     css::uno::Reference< css::lang::XMultiServiceFactory > xFactory(m_xSMGR->createInstance(SERVICENAME_CONTENTHANDLERFACTORY), css::uno::UNO_QUERY);
     css::uno::Reference< css::container::XContainerQuery > xQuery  (xFactory                                                  , css::uno::UNO_QUERY);
 
@@ -1146,7 +1146,7 @@ sal_Bool LoadEnv::impl_loadContent()
     // if it will be run out of scope.
 
     // Note further: ignore if this internal guard already contains a resource.
-    // Might impl_searchRecylcTarget() set it before. But incase this impl-method wasnt used
+    // Might impl_searchRecylcTarget() set it before. But incase this impl-method wasn't used
     // and the target frame was new created ... this lock here must be set!
     css::uno::Reference< css::document::XActionLockable > xTargetLock(xTargetFrame, css::uno::UNO_QUERY);
     m_aTargetLock.setResource(xTargetLock);
@@ -1242,7 +1242,7 @@ css::uno::Reference< css::uno::XInterfac
 
     // Otherwhise ...
     // We need this type information to locate an registered frame loader
-    // Without such information we cant work!
+    // Without such information we can't work!
     ::rtl::OUString sType = m_lMediaDescriptor.getUnpackedValueOrDefault(::comphelper::MediaDescriptor::PROP_TYPENAME(), ::rtl::OUString());
     if (!sType.getLength())
         throw LoadEnvException(LoadEnvException::ID_INVALID_MEDIADESCRIPTOR);
@@ -1340,7 +1340,7 @@ css::uno::Reference< css::frame::XFrame 
     }
 
     // check URL
     // May its not usefull to start expensive document search, if it
     // can fail only .. because we load from a stream or model directly!
     if (
         (ProtocolCheck::isProtocol(m_aURL.Complete, ProtocolCheck::E_PRIVATE_STREAM )) ||
@@ -1360,7 +1360,7 @@ css::uno::Reference< css::frame::XFrame 
         return css::uno::Reference< css::frame::XFrame >(); // task list can be empty!
 
     // Note: To detect if a document was alrady loaded before
-    // we check URLs here only. But might the existing and the requred
+    // we check URLs here only. But might the existing and the required
     // document has different versions! Then its URLs are the same ...
     sal_Int16 nNewVersion = m_lMediaDescriptor.getUnpackedValueOrDefault(::comphelper::MediaDescriptor::PROP_VERSION(), (sal_Int16)(-1));
 
@@ -1406,7 +1406,7 @@ css::uno::Reference< css::frame::XFrame 
 			}
 
             // get the original load arguments from the current document
-            // and decide if its realy the same then the one will be.
+            // and decide if its really the same then the one will be.
             // It must be visible and must use the same file revision ...
             // or must not have any file revision set (-1 == -1!)
             ::comphelper::MediaDescriptor lOldDocDescriptor(xModel->getArgs());
@@ -1641,7 +1641,7 @@ void LoadEnv::impl_reactForLoadingState(
         {
             ::vos::OClearableGuard aSolarGuard(Application::GetSolarMutex());
             Window* pWindow = VCLUnoHelper::GetWindow(xWindow);
             // check for system window is neccessary to guarantee correct pointer cast!
             if (pWindow && pWindow->IsSystemWindow())
                 ((WorkWindow*)pWindow)->Minimize();
         }
@@ -1661,7 +1661,7 @@ void LoadEnv::impl_reactForLoadingState(
         {
             ::rtl::OUString sFrameName;
             pFrameName->second >>= sFrameName;
-            // Check the name again. e.g. "_default" isnt allowed.
+            // Check the name again. e.g. "_default" isn't allowed.
             // On the other side "_beamer" is a valid name :-)
             if (TargetHelper::isValidNameForFrame(sFrameName))
                 m_xTargetFrame->setName(sFrameName);
@@ -944,7 +944,7 @@ sal_Bool LoadEnv::impl_handleContent()
     css::util::URL aURL = m_aURL;
 
-    // get neccessary container to query for a handler object
+    // get necessary container to query for a handler object
     css::uno::Reference< css::lang::XMultiServiceFactory > xFactory(m_xSMGR->createInstance(SERVICENAME_CONTENTHANDLERFACTORY), css::uno::UNO_QUERY);
     css::uno::Reference< css::container::XContainerQuery > xQuery  (xFactory                                                  , css::uno::UNO_QUERY);
@@ -1340,7 +1340,7 @@ css::uno::Reference< css::frame::XFrame 
 
     // check URL
-    // May its not usefull to start expensive document search, if it
+    // May its not useful to start expensive document search, if it
     // can fail only .. because we load from a stream or model directly!
     if (
@@ -1641,7 +1641,7 @@ void LoadEnv::impl_reactForLoadingState(
             ::vos::OClearableGuard aSolarGuard(Application::GetSolarMutex());
             Window* pWindow = VCLUnoHelper::GetWindow(xWindow);
-            // check for system window is neccessary to guarantee correct pointer cast!
+            // check for system window is necessary to guarantee correct pointer cast!
             if (pWindow && pWindow->IsSystemWindow())
                 ((WorkWindow*)pWindow)->Minimize();

Modified: openoffice/trunk/main/framework/source/loadenv/targethelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/loadenv/targethelper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================